==> eboard-0.5.1.tar.gz: eboard-0.5.1/proto_crafty.cc <==
/* $Id: proto_crafty.cc,v 1.24 2002/04/24 05:25:09 bergo Exp $ */

/*

    eboard - chess client
    http://eboard.sourceforge.net
    Copyright (C) 2000-2002 Felipe Paulo Guazzi Bergo
    bergo@seul.org

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/

#include <iostream.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include "eboard.h"
#include "global.h"
#include "network.h"
#include "protocol.h"
#include "chess.h"
#include "status.h"
#include "util.h"

CraftyProtocolParser::CraftyProtocolParser() : XBoardProtocolParser() {
  strcpy(ComputerName,"Crafty");
  want_path_pane=0;
}

char * CraftyProtocolParser::getDialogName() {
  return("Play against Crafty");
}

void CraftyProtocolParser::readDialog() {
  XBoardProtocolParser::readDialog();
  resolvePaths();
  sprintf(EngineCommandLine,"crafty bookpath=%s logpath=%s tbpath=%s",
	  BookPath,LogPath,LogPath);
  if (!global.env.Home.empty())
    sprintf(EngineRunDir,"%s/.eboard/craftylog",global.env.Home.c_str());
  else
    strcpy(EngineRunDir,"/tmp");

  if (ebm) {
    ebm->proto     = 1;
    ebm->cmdline   = EngineCommandLine;
    ebm->directory = EngineRunDir;
    makeBookmarkCaption();
  }
}

void CraftyProtocolParser::initEngine() {
  global.network->writeLine("log off");
  XBoardProtocolParser::initEngine();
}

// keep this and Documentation/Crafty.txt coherent
void CraftyProtocolParser::resolvePaths() {
  FileFinder ff;
  char z[256],zz[256],*p;

  // book path
  if (!global.env.Home.empty())
    sprintf(z,"%s/.eboard",global.env.Home.c_str());
  else
    strcpy(z,"/tmp");

  ff.addMyDirectory(".eboard");
  ff.addMyDirectory(".");
  ff.addDirectory("/usr/local/share/eboard");
  ff.addDirectory("/usr/share/eboard");
  ff.addDirectory("/usr/local/share/crafty");
  ff.addDirectory("/usr/share/crafty");

  if (ff.find("book.bin",zz)) {
    p=rindex(zz,'/');
    *p=0;
  } else
    strcpy(zz,z);

  strcpy(BookPath,zz);

  // log path
  if (!global.env.Home.empty())
    sprintf(z,"%s/.eboard/craftylog",global.env.Home.c_str());
  else
    strcpy(z,"/tmp");
  strcpy(LogPath,z);
}

==> eboard-0.6.2.tar.gz: eboard-0.6.2/proto_crafty.cc <==
/* $Id: proto_crafty.cc,v 1.26 2002/06/17 03:24:31 bergo Exp $ */

/*

    eboard - chess client
    http://eboard.sourceforge.net
    Copyright (C) 2000-2002 Felipe Paulo Guazzi Bergo
    bergo@seul.org

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include <iostream.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>

#ifdef HAVE_STRINGS_H
#include <strings.h>
#endif

#include "eboard.h"
#include "global.h"
#include "network.h"
#include "protocol.h"
#include "chess.h"
#include "status.h"
#include "util.h"

CraftyProtocol::CraftyProtocol() : XBoardProtocol() {
  strcpy(ComputerName,"Crafty");
  want_path_pane=0;
}

char * CraftyProtocol::getDialogName() {
  return("Play against Crafty");
}

void CraftyProtocol::readDialog() {
  XBoardProtocol::readDialog();
  resolvePaths();
  sprintf(EngineCommandLine,"crafty bookpath=%s logpath=%s tbpath=%s",
	  BookPath,LogPath,LogPath);
  if (!global.env.Home.empty())
    sprintf(EngineRunDir,"%s/.eboard/craftylog",global.env.Home.c_str());
  else
    strcpy(EngineRunDir,"/tmp");

  if (ebm) {
    ebm->proto     = 1;
    ebm->cmdline   = EngineCommandLine;
    ebm->directory = EngineRunDir;
    makeBookmarkCaption();
  }
}

void CraftyProtocol::initEngine() {
  global.network->writeLine("log off");
  XBoardProtocol::initEngine();
}

// keep this and Documentation/Crafty.txt coherent
void CraftyProtocol::resolvePaths() {
  FileFinder ff;
  char z[256],zz[256],*p;

  // book path
  if (!global.env.Home.empty())
    sprintf(z,"%s/.eboard",global.env.Home.c_str());
  else
    strcpy(z,"/tmp");

  ff.addMyDirectory(".eboard");
  ff.addMyDirectory(".");
  ff.addDirectory("/usr/local/share/eboard");
  ff.addDirectory("/usr/share/eboard");
  ff.addDirectory("/usr/local/share/crafty");
  ff.addDirectory("/usr/share/crafty");

  if (ff.find("book.bin",zz)) {
    p=rindex(zz,'/');
    *p=0;
  } else
    strcpy(zz,z);

  strcpy(BookPath,zz);

  // log path
  if (!global.env.Home.empty())
    sprintf(z,"%s/.eboard/craftylog",global.env.Home.c_str());
  else
    strcpy(z,"/tmp");
  strcpy(LogPath,z);
}
